==> Agi4x44PreProcess_1.2.0.zip: Agi4x44PreProcess/doc/Agi4x44PreProcess.R <==
###################################################
### chunk number 1: 
###################################################
library("hgug4112a.db")


###################################################
### chunk number 2: data
###################################################
library("Agi4x44PreProcess")
data(targets)
targets


###################################################
### chunk number 3: data
###################################################
data(dd) 
class(dd)
dim(dd)


###################################################
### chunk number 4: 
###################################################
names(dd)


###################################################
### chunk number 5: BoxPlot1
###################################################
BoxPlot(log2(dd$R),"ProcessedSignal", "red",
xlab="Samples", ylab="expression")


###################################################
### chunk number 6: plotDensity1
###################################################
plotDensity(log2(dd$R),"ProcessedSignal")


###################################################
### chunk number 7: BoxPlot2
###################################################
BoxPlot(log2(dd$G),"MeanSignal", "green",
xlab="Samples", ylab="expression")


###################################################
### chunk number 8: plotDensity2
###################################################
plotDensity(log2(dd$G),"MeanSignal")


###################################################
### chunk number 9: BoxPlot3
###################################################
BoxPlot(log2(dd$Gb),"BGUsed", "orange",
xlab="Samples", ylab="expression")


###################################################
### chunk number 10: BoxPlot4
###################################################
BoxPlot(log2(dd$Rb),"BGMedianSignal", "blue",
xlab="Samples", ylab="expression")


###################################################
### chunk number 11: CV.rep.probes
###################################################
CV.rep.probes(dd,"hgug4112a.db",
               	foreground="MeanSignal", raw.data=TRUE,
		writeR=FALSE, targets)


###################################################
### chunk number 12: genes.rpt.agi
###################################################
genes.rpt.agi(dd,"hgug4112a.db",raw.data=TRUE,
               WRITE.html=FALSE,REPORT=FALSE)


###################################################
### chunk number 13: BGandNorm
###################################################
ddNORM=BGandNorm(dd,BGmethod="half",NORMmethod="quantile",
                 foreground="MeanSignal",background="BGMedianSignal",
                 offset=50,makePLOTpre=FALSE,makePLOTpost=FALSE)


###################################################
### chunk number 14: filter.probes
###################################################
ddFILT=filter.probes(ddNORM,
                control=TRUE,
                wellaboveBG=TRUE,
                isfound=TRUE,
                wellaboveNEG=TRUE,
                sat=TRUE,
                PopnOL=TRUE,
                NonUnifOL=T,
                nas=TRUE,
                limWellAbove=75,
                limISF=75,
                limNEG=75,
                limSAT=75,
                limPopnOL=75,
                limNonUnifOL=75,
                limNAS=100,
                makePLOT=F,annotation.package="hgug4112a.db",flag.counts=T,targets)


###################################################
### chunk number 15: 
###################################################
dim(ddFILT)


###################################################
### chunk number 16: summarize.probe
###################################################
ddPROC=summarize.probe(ddFILT, makePLOT=FALSE, targets)


###################################################
### chunk number 17: build.eset
###################################################
esetPROC=build.eset(ddPROC, targets, makePLOT=FALSE,
                annotation.package="hgug4112a.db")


###################################################
### chunk number 18: BoxPlot eval=FALSE
###################################################
## BoxPlot(log2(dd$G),"MeanSignal","green",
## xlab="Samples",ylab="expression")


###################################################
### chunk number 19: boxplotNegCtrl
###################################################
boxplotNegCtrl(dd,Log2=FALSE, channel="G")


###################################################
### chunk number 20: plotDensity eval=FALSE
###################################################
## plotDensity(log2(dd$G),"Density Plot example")


###################################################
### chunk number 21: MVAplotMEDctrl eval=FALSE
###################################################
## 
## par(mfrow=c(2,2),ask=TRUE)	
## MVAplotMEDctrl(dd,"MVA example",channel="G")


###################################################
### chunk number 22: MVAplotMED eval=FALSE
###################################################
## par(mfrow=c(2,2))
## MVAplotMED(dd$G,"red","MVA example")


###################################################
### chunk number 23: RLE
###################################################
par(mfrow=c(1,1))	
RLE(log2(dd$G),"RLE example ","orange")



###################################################
### chunk number 24: HeatMap
###################################################
HeatMap(exprs(esetPROC),size=100,"100 High Var genes")


###################################################
### chunk number 25: hierclus
###################################################

data(targets)
GErep=targets$Gerep 
hierclus(exprs(esetPROC),GErep,methdis="euclidean",
        methclu="complete",sel=FALSE,size = 100)



###################################################
### chunk number 26: PCAplot eval=FALSE
###################################################
## 
## data(targets)
## PCAplot(esetPROC,targets)

==> Agi4x44PreProcess_1.10.0.zip: Agi4x44PreProcess/doc/Agi4x44PreProcess.R <==
###################################################
### chunk number 1: 
###################################################
#line 61 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpzFEGA1/R.INSTALL54a07661/Agi4x44PreProcess/inst/doc/Agi4x44PreProcess.Rnw"
library("hgug4112a.db")


###################################################
### chunk number 2: data
###################################################
#line 110 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpzFEGA1/R.INSTALL54a07661/Agi4x44PreProcess/inst/doc/Agi4x44PreProcess.Rnw"
library("Agi4x44PreProcess")
data(targets)
targets


###################################################
### chunk number 3: data
###################################################
#line 180 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpzFEGA1/R.INSTALL54a07661/Agi4x44PreProcess/inst/doc/Agi4x44PreProcess.Rnw"
data(dd) 
class(dd)
dim(dd)


###################################################
### chunk number 4: 
###################################################
#line 188 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpzFEGA1/R.INSTALL54a07661/Agi4x44PreProcess/inst/doc/Agi4x44PreProcess.Rnw"
names(dd)


###################################################
### chunk number 5: BoxPlot1
###################################################
#line 284 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpzFEGA1/R.INSTALL54a07661/Agi4x44PreProcess/inst/doc/Agi4x44PreProcess.Rnw"
BoxPlot(log2(dd$R),"ProcessedSignal", "red",
xlab="Samples", ylab="expression")


###################################################
### chunk number 6: plotDensity1
###################################################
#line 291 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpzFEGA1/R.INSTALL54a07661/Agi4x44PreProcess/inst/doc/Agi4x44PreProcess.Rnw"
plotDensity(log2(dd$R),"ProcessedSignal")


###################################################
### chunk number 7: BoxPlot2
###################################################
#line 297 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpzFEGA1/R.INSTALL54a07661/Agi4x44PreProcess/inst/doc/Agi4x44PreProcess.Rnw"
BoxPlot(log2(dd$G),"MeanSignal", "green",
xlab="Samples", ylab="expression")


###################################################
### chunk number 8: plotDensity2
###################################################
#line 304 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpzFEGA1/R.INSTALL54a07661/Agi4x44PreProcess/inst/doc/Agi4x44PreProcess.Rnw"
plotDensity(log2(dd$G),"MeanSignal")


###################################################
### chunk number 9: BoxPlot3
###################################################
#line 310 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpzFEGA1/R.INSTALL54a07661/Agi4x44PreProcess/inst/doc/Agi4x44PreProcess.Rnw"
BoxPlot(log2(dd$Gb),"BGUsed", "orange",
xlab="Samples", ylab="expression")


###################################################
### chunk number 10: BoxPlot4
###################################################
#line 317 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpzFEGA1/R.INSTALL54a07661/Agi4x44PreProcess/inst/doc/Agi4x44PreProcess.Rnw"
BoxPlot(log2(dd$Rb),"BGMedianSignal", "blue",
xlab="Samples", ylab="expression")


###################################################
### chunk number 11: CV.rep.probes
###################################################
#line 350 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpzFEGA1/R.INSTALL54a07661/Agi4x44PreProcess/inst/doc/Agi4x44PreProcess.Rnw"
CV.rep.probes(dd,"hgug4112a.db",
               	foreground="MeanSignal", raw.data=TRUE,
		writeR=FALSE, targets)


###################################################
### chunk number 12: genes.rpt.agi
###################################################
#line 381 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpzFEGA1/R.INSTALL54a07661/Agi4x44PreProcess/inst/doc/Agi4x44PreProcess.Rnw"
genes.rpt.agi(dd,"hgug4112a.db",raw.data=TRUE,
               WRITE.html=FALSE,REPORT=FALSE)


###################################################
### chunk number 13: BGandNorm
###################################################
#line 456 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpzFEGA1/R.INSTALL54a07661/Agi4x44PreProcess/inst/doc/Agi4x44PreProcess.Rnw"
ddNORM=BGandNorm(dd,BGmethod="half",NORMmethod="quantile",
                 foreground="MeanSignal",background="BGMedianSignal",
                 offset=50,makePLOTpre=FALSE,makePLOTpost=FALSE)


###################################################
### chunk number 14: filter.probes
###################################################
#line 593 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpzFEGA1/R.INSTALL54a07661/Agi4x44PreProcess/inst/doc/Agi4x44PreProcess.Rnw"
ddFILT=filter.probes(ddNORM,
                control=TRUE,
                wellaboveBG=TRUE,
                isfound=TRUE,
                wellaboveNEG=TRUE,
                sat=TRUE,
                PopnOL=TRUE,
                NonUnifOL=T,
                nas=TRUE,
                limWellAbove=75,
                limISF=75,
                limNEG=75,
                limSAT=75,
                limPopnOL=75,
                limNonUnifOL=75,
                limNAS=100,
                makePLOT=F,annotation.package="hgug4112a.db",flag.counts=T,targets)


###################################################
### chunk number 15: 
###################################################
#line 613 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpzFEGA1/R.INSTALL54a07661/Agi4x44PreProcess/inst/doc/Agi4x44PreProcess.Rnw"
dim(ddFILT)


###################################################
### chunk number 16: summarize.probe
###################################################
#line 655 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpzFEGA1/R.INSTALL54a07661/Agi4x44PreProcess/inst/doc/Agi4x44PreProcess.Rnw"
ddPROC=summarize.probe(ddFILT, makePLOT=FALSE, targets)


###################################################
### chunk number 17: build.eset
###################################################
#line 670 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpzFEGA1/R.INSTALL54a07661/Agi4x44PreProcess/inst/doc/Agi4x44PreProcess.Rnw"
esetPROC=build.eset(ddPROC, targets, makePLOT=FALSE,
                annotation.package="hgug4112a.db")


###################################################
### chunk number 18: BoxPlot eval=FALSE
###################################################
## #line 744 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpzFEGA1/R.INSTALL54a07661/Agi4x44PreProcess/inst/doc/Agi4x44PreProcess.Rnw"
## BoxPlot(log2(dd$G),"MeanSignal","green",
## xlab="Samples",ylab="expression")


###################################################
### chunk number 19: boxplotNegCtrl
###################################################
#line 753 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpzFEGA1/R.INSTALL54a07661/Agi4x44PreProcess/inst/doc/Agi4x44PreProcess.Rnw"
boxplotNegCtrl(dd,Log2=FALSE, channel="G")


###################################################
### chunk number 20: plotDensity eval=FALSE
###################################################
## #line 774 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpzFEGA1/R.INSTALL54a07661/Agi4x44PreProcess/inst/doc/Agi4x44PreProcess.Rnw"
## plotDensity(log2(dd$G),"Density Plot example")


###################################################
### chunk number 21: MVAplotMEDctrl eval=FALSE
###################################################
## #line 794 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpzFEGA1/R.INSTALL54a07661/Agi4x44PreProcess/inst/doc/Agi4x44PreProcess.Rnw"
## 
## par(mfrow=c(2,2),ask=TRUE)	
## MVAplotMEDctrl(dd,"MVA example",channel="G")


###################################################
### chunk number 22: MVAplotMED eval=FALSE
###################################################
## #line 809 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpzFEGA1/R.INSTALL54a07661/Agi4x44PreProcess/inst/doc/Agi4x44PreProcess.Rnw"
## par(mfrow=c(2,2))
## MVAplotMED(dd$G,"red","MVA example")


###################################################
### chunk number 23: RLE
###################################################
#line 828 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpzFEGA1/R.INSTALL54a07661/Agi4x44PreProcess/inst/doc/Agi4x44PreProcess.Rnw"
par(mfrow=c(1,1))	
RLE(log2(dd$G),"RLE example ","orange")



###################################################
### chunk number 24: HeatMap
###################################################
#line 845 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpzFEGA1/R.INSTALL54a07661/Agi4x44PreProcess/inst/doc/Agi4x44PreProcess.Rnw"
HeatMap(exprs(esetPROC),size=100,"100 High Var genes")


###################################################
### chunk number 25: hierclus
###################################################
#line 860 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpzFEGA1/R.INSTALL54a07661/Agi4x44PreProcess/inst/doc/Agi4x44PreProcess.Rnw"

data(targets)
GErep=targets$Gerep 
hierclus(exprs(esetPROC),GErep,methdis="euclidean",
        methclu="complete",sel=FALSE,size = 100)



###################################################
### chunk number 26: PCAplot eval=FALSE
###################################################
## #line 878 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpzFEGA1/R.INSTALL54a07661/Agi4x44PreProcess/inst/doc/Agi4x44PreProcess.Rnw"
## 
## data(targets)
## PCAplot(esetPROC,targets)
